bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.add_plate_axis
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.add_plate_axis